@@ -4,7 +4,7 @@ from datetime import datetime
 import json
 import io
 from pathlib import Path
-import files_sdk.models.file_action as file_action
+from . import file_action
 from files_sdk.api import Api
 from files_sdk.exceptions import InvalidParameterError, MissingParameterError, NotImplementedError
 
@@ -310,11 +310,8 @@ def find(path, params = {}, options = {}):
         self.delete(params)
 
     def save(self):
-        if hasattr(self, "path") and self.path:
-            self.update(self.get_attributes())
-        else:
-            new_obj = create(self.get_attributes(), self.options)
-            self.set_attributes(new_obj.get_attributes())
+        new_obj = create(self.path, self.get_attributes(), self.options)
+        self.set_attributes(new_obj.get_attributes())
 
 # Download file
 #
