@@ -27,6 +27,7 @@ class HistoryExport:
         'query_target_username': None,     # string - If searching for Histories about API keys, this parameter restricts results to API keys created by/for this username.
         'query_target_platform': None,     # string - If searching for Histories about API keys, this parameter restricts results to API keys associated with this platform.
         'query_target_permission_set': None,     # string - If searching for Histories about API keys, this parameter restricts results to API keys with this permission set.
+        'results_url': None,     # string - If `status` is `ready` and the query succeeded, this will be a URL where all the results can be downloaded at once as a CSV.
         'user_id': None,     # int64 - User ID.  Provide a value of `0` to operate the current session's user.
     }
 
@@ -41,23 +42,6 @@ class HistoryExport:
     def get_attributes(self):
         return {k: getattr(self, k, None) for k in HistoryExport.default_attributes if getattr(self, k, None) is not None}
 
-    def delete(self, params = {}):
-        if not isinstance(params, dict):
-            params = {}
-
-        if hasattr(self, "id") and self.id:
-            params['id'] = self.id
-        else:
-            raise MissingParameterError("Current object doesn't have a id")
-        if "id" not in params:
-            raise MissingParameterError("Parameter missing: id")
-        if "id" in params and not isinstance(params["id"], int):
-            raise InvalidParameterError("Bad parameter: id must be an int")
-        response, _options = Api.send_request("DELETE", "/history_exports/{id}".format(id=params['id']), params, self.options)
-        return response.data
-
-    def destroy(self, params = {}):
-        self.delete(params)
 
     def save(self):
         if hasattr(self, "id") and self.id:
@@ -66,26 +50,6 @@ class HistoryExport:
             new_obj = create(self.get_attributes(), self.options)
             self.set_attributes(new_obj.get_attributes())
 
-# Parameters:
-#   user_id - int64 - User ID.  Provide a value of `0` to operate the current session's user.
-#   page - int64 - Current page number.
-#   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
-#   action - string - Deprecated: If set to `count` returns a count of matching records rather than the records themselves.
-def list(params = {}, options = {}):
-    if "user_id" in params and not isinstance(params["user_id"], int):
-        raise InvalidParameterError("Bad parameter: user_id must be an int")
-    if "page" in params and not isinstance(params["page"], int):
-        raise InvalidParameterError("Bad parameter: page must be an int")
-    if "per_page" in params and not isinstance(params["per_page"], int):
-        raise InvalidParameterError("Bad parameter: per_page must be an int")
-    if "action" in params and not isinstance(params["action"], str):
-        raise InvalidParameterError("Bad parameter: action must be an str")
-    response, options = Api.send_request("GET", "/history_exports", params, options)
-    return [ HistoryExport(entity_data, options) for entity_data in response.data ]
-
-def all(params = {}, options = {}):
-    list(params, options)
-
 # Parameters:
 #   id (required) - int64 - History Export ID.
 def find(id, params = {}, options = {}):
@@ -173,19 +137,5 @@ def create(params = {}, options = {}):
     response, options = Api.send_request("POST", "/history_exports", params, options)
     return HistoryExport(response.data, options)
 
-def delete(id, params = {}, options = {}):
-    if not isinstance(params, dict):
-        params = {}
-    params["id"] = id
-    if "id" in params and not isinstance(params["id"], int):
-        raise InvalidParameterError("Bad parameter: id must be an int")
-    if "id" not in params:
-        raise MissingParameterError("Parameter missing: id")
-    response, _options = Api.send_request("DELETE", "/history_exports/{id}".format(id=params['id']), params, options)
-    return response.data
-
-def destroy(id, params = {}, options = {}):
-    delete(id, params, options)
-
 def new(*args, **kwargs):
     return HistoryExport(*args, **kwargs)
\ No newline at end of file
